Optimizers (``taurex.optimizer``)
=================================


Base
----

.. automodule:: taurex.optimizer.optimizer
   :members:
   :undoc-members:
   :show-inheritance:

Nestle (``taurex.optimizer.nestle``)
------------------------------------

.. automodule:: taurex.optimizer.nestle
   :members:
   :undoc-members:
   :show-inheritance:

MultiNest (``taurex.optimizer.multinest``)
------------------------------------------

.. automodule:: taurex.optimizer.multinest
   :members:
   :show-inheritance:

PolyChord (``taurex.optimizer.polychord``)
------------------------------------------

.. automodule:: taurex.optimizer.polychord
   :members:
   :show-inheritance:

dyPolyChord (``taurex.optimizer.dypolychord``)
----------------------------------------------

.. automodule:: taurex.optimizer.dypolychord
   :members:
   :show-inheritance:
